@@ -381,7 +381,7 @@ void PartitionTable::insertUnallocated(const Device& d, PartitionNode* p, qint64
     if (d.type() == Device::LVM_Device && !p->children().isEmpty()) {
         // rearranging the sectors of all partitions to keep unallocated space at the end
         lastEnd = 0;
-        qSort(children().begin(), children().end(), [](const Partition* p1, const Partition* p2) { return p1->deviceNode() < p2->deviceNode(); });
+        std::sort(children().begin(), children().end(), [](const Partition* p1, const Partition* p2) { return p1->deviceNode() < p2->deviceNode(); });
         for (const auto &child : children()) {
             qint64 totalSectors = child->length();
             child->setFirstSector(lastEnd);
@@ -566,17 +566,19 @@ QTextStream& operator<<(QTextStream& stream, const PartitionTable& ptable)
         if (!p->roles().has(PartitionRole::Unallocated)) {
             partitions.append(p);
 
-            if (p->roles().has(PartitionRole::Extended))
-                for (const auto &child : p->children()) {
+            if (p->roles().has(PartitionRole::Extended)) {
+                const auto partChildren = p->children();
+                for (const auto &child : partChildren) {
                     if (!child->roles().has(PartitionRole::Unallocated))
                         partitions.append(child);
                 }
+            }
         }
     }
 
-    qSort(partitions.begin(), partitions.end(), [](const Partition* p1, const Partition* p2) { return p1->number() < p2->number(); });
+    std::sort(partitions.begin(), partitions.end(), [](const Partition* p1, const Partition* p2) { return p1->number() < p2->number(); });
 
-    foreach(const auto &p, partitions)
+    for (const auto &p : qAsConst(partitions))
         stream << *p;
 
     return stream;
