@@ -43,7 +43,7 @@ public:
     fat32(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
 
 public:
-    bool create(Report& report, const QString& deviceNode) const override;
+    bool create(Report& report, const QString& deviceNode) override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
 
     qint64 minCapacity() const override;
