@@ -70,7 +70,7 @@ void SetPartFlagsOperation::undo()
 QString SetPartFlagsOperation::description() const
 {
     if (PartitionTable::flagNames(newFlags()).size() == 0)
-        return xi18nc("@info/plain", "Clear flags for partition <filename>%1</filename>", flagPartition().deviceNode());
+        return xi18nc("@info:status", "Clear flags for partition <filename>%1</filename>", flagPartition().deviceNode());
 
-    return xi18nc("@info/plain", "Set flags for partition <filename>%1</filename> to \"%2\"", flagPartition().deviceNode(), PartitionTable::flagNames(newFlags()).join(QStringLiteral(",")));
+    return xi18nc("@info:status", "Set flags for partition <filename>%1</filename> to \"%2\"", flagPartition().deviceNode(), PartitionTable::flagNames(newFlags()).join(QStringLiteral(",")));
 }
