@@ -45,6 +45,10 @@
 #include <blkid/blkid.h>
 
 #include <QDebug>
+#include <QFile>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
 #include <QString>
 #include <QStringList>
 
@@ -411,37 +415,45 @@ Device* LibPartedBackend::scanDevice(const QString& deviceNode)
 
 QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
 {
+//  TODO: add another bool option for loopDevices
     QList<Device*> result;
-    // linux.git/tree/Documentation/devices.txt
-    QString blockDeviceMajorNumbers = QStringLiteral(
-        "3,22,33,34,56,57,88,89,90,91,128,129,130,131,132,133,134,135," // MFM, RLL and IDE hard disk/CD-ROM interface
-        // "7," // loop devices TODO: add another bool option for loopDevices
-        "8,65,66,67,68,69,70,71," // SCSI disk devices
-        "80,81,82,83,84,85,86,87," // I2O hard disk
-        "179," // MMC block devices
-        "253," // Virtio KVM devices (e.g. /dev/vda)
-        "259" // Block Extended Major (include NVMe)
-    );
-    ExternalCommand cmd(QStringLiteral("lsblk"), {
-                          QStringLiteral("--nodeps"),
-                          QStringLiteral("--noheadings"),
-                          QStringLiteral("--output"), QString::fromLatin1("name"),
+    QStringList deviceNodes;
+
+    ExternalCommand cmd(QStringLiteral("lsblk"),
+                        { QStringLiteral("--nodeps"),
                           QStringLiteral("--paths"),
-                          QStringLiteral("--include"), blockDeviceMajorNumbers});
+                          QStringLiteral("--sort"), QStringLiteral("name"),
+                          QStringLiteral("--json"),
+                          QStringLiteral("--output"),
+                          QStringLiteral("type,name") });
+
     if (cmd.run(-1) && cmd.exitCode() == 0) {
-        QStringList devices = cmd.output().split(QString::fromLatin1("\n"));
-        devices.removeLast();
-        quint32 totalDevices = devices.length();
-        for (quint32 i = 0; i < totalDevices; ++i) {
+        const QJsonDocument jsonDocument = QJsonDocument::fromJson(cmd.output().toUtf8());
+        QJsonObject jsonObject = jsonDocument.object();
+        const QJsonArray jsonArray = jsonObject[QLatin1String("blockdevices")].toArray();
+        for (const auto &deviceLine : jsonArray) {
+            QJsonObject deviceObject = deviceLine.toObject();
+            if (deviceObject[QLatin1String("type")].toString() != QLatin1String("disk"))
+                continue;
+
+            const QString deviceNode = deviceObject[QLatin1String("name")].toString();
             if (excludeReadOnly) {
-                QFile f(QStringLiteral("/sys/block/%1/ro").arg(QString(devices[i]).remove(QStringLiteral("/dev/"))));
+                QString deviceName = deviceNode;
+                deviceName.remove(QStringLiteral("/dev/"));
+                QFile f(QStringLiteral("/sys/block/%1/ro").arg(deviceName));
                 if (f.open(QIODevice::ReadOnly))
                     if (f.readLine().trimmed().toInt() == 1)
                         continue;
             }
+            deviceNodes << deviceNode;
+        }
 
-            emitScanProgress(devices[i], i * 100 / totalDevices);
-            Device* device = scanDevice(devices[i]);
+        quint32 totalDevices = deviceNodes.length();
+        for (quint32 i = 0; i < totalDevices; ++i) {
+            const QString deviceNode = deviceNodes[i];
+
+            emitScanProgress(deviceNode, i * 100 / totalDevices);
+            Device* device = scanDevice(deviceNode);
             if(device != nullptr) {
                 result.append(device);
             }
